@@ -1,7 +1,9 @@
-############################################################################
+
+#####
 #
 # TOra - An Oracle Toolkit for DBA's and developers
-# Copyright (C) 2003 Quest Software, Inc
+# Copyright (C) 2003-2005 Quest Software, Inc
+# Portions Copyright (C) 2005 Other Contributors
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -28,9 +30,11 @@
 #      these libraries without written consent from Quest Software, Inc.
 #      Observe that this does not disallow linking to the Qt Free Edition.
 #
+#      You may link this product with any GPL'd Qt library such as Qt/Free
+#
 # All trademarks belong to their respective owners.
 #
-############################################################################
+#####
 
 use strict;
 use File::Copy;
@@ -505,7 +509,9 @@ __TEMP__
     }
     close TEMP;
     if (!system("$gcc $LFlags -I`pwd` $Includes $Libs $QtLibShared $TestDB -o $tmpName $tmpName.cpp")) {
-        $ENV{"LD_LIBRARY_PATH"}=$ENV{"LD_LIBRARY_PATH"}.":".$ENV{"ORACLE_HOME"}."/lib";
+        $ENV{"LD_LIBRARY_PATH"} .= ":".$ENV{"ORACLE_HOME"}."/lib32";
+        $ENV{"LD_LIBRARY_PATH"} .= ":".$ENV{"ORACLE_HOME"}."/lib";
+        $ENV{"LD_LIBRARY_PATH"} .= ":".$ENV{"ORACLE_HOME"};
 	if (!system($tmpName)) {
 	    $CC=$gcc;
 	}
@@ -1007,7 +1013,9 @@ __TEMP__
     }
     print "\n";
 
+    $LFlags.="\"-L".$ENV{ORACLE_HOME}."/lib32\" ";
     $LFlags.="\"-L".$ENV{ORACLE_HOME}."/lib\" ";
+    $LFlags.="\"-L".$ENV{ORACLE_HOME}."\" ";
     $LFlags.="\"-L".$QtLib."\" ";
     if ($OracleRelease =~ /^8.0/) {
         $LFlags.="\"$ENV{ORACLE_HOME}/lib/scorept.o\" ";
@@ -1039,13 +1047,20 @@ __TEMP__
     print "$extra\n";
 
     if (!$NoRPath) {
-	$LFlags.="-Xlinker \"--rpath=".$ENV{ORACLE_HOME}."/lib\" -Xlinker \"--rpath\=$QtLib\" ";
+	$LFlags.="-Xlinker \"--rpath=".$ENV{ORACLE_HOME}."/lib32\" ";
+	$LFlags.="-Xlinker \"--rpath=".$ENV{ORACLE_HOME}."/lib\" ";
+	$LFlags.="-Xlinker \"--rpath=".$ENV{ORACLE_HOME}."\" ";
+	$LFlags.="-Xlinker \"--rpath\=$QtLib\" ";
     }
 
     $Includes=&addInclude($Includes,$ENV{ORACLE_HOME}."/rdbms/demo");
     $Includes=&addInclude($Includes,$ENV{ORACLE_HOME}."/plsql/public");
     $Includes=&addInclude($Includes,$ENV{ORACLE_HOME}."/rdbms/public");
     $Includes=&addInclude($Includes,$ENV{ORACLE_HOME}."/network/public");
+    $Includes=&addInclude($Includes,$ENV{ORACLE_HOME}."/sdk/include");
+    if ( $ENV{C_INCLUDE_PATH} ) {
+      $Includes=&addInclude($Includes,$ENV{C_INCLUDE_PATH});
+    }
     $Includes=&addInclude($Includes,$QtInclude);
 
     if (!$ForceTarget) {
@@ -1282,9 +1297,9 @@ __EOT__
 	print MAKEFILE "PERL=$Perl\n";
 	print MAKEFILE "\n";
 
-	print MAKEFILE "# Comment out this line if you want more output from compile\n";
-	print MAKEFILE ".SILENT:\n";
-	print MAKEFILE "\n";
+	#print MAKEFILE "# Comment out this line if you want more output from compile\n";
+	#print MAKEFILE ".SILENT:\n";
+	#print MAKEFILE "\n";
 
 	print MAKEFILE <<__EOT__;
 # Additional flags set when using only the precompiler.
@@ -1376,10 +1391,6 @@ __EOT__
 	print MAKEFILE "\t".join(".cpp \\\n\t",sort @allsource).
 	    ".cpp\n\ndefault: all\n";
 
-	if ($OracleFound) {
-	    print MAKEFILE "include \$(ORACLE_HOME)/rdbms/lib/env_rdbms.mk\n";
-	}
-
 	print MAKEFILE "\nTRANSLATIONS=\\\n";
 	for my $t (@translations) {
 	    print MAKEFILE "\t$t.ts\\\n";
@@ -1581,8 +1592,7 @@ $ProgramName-static: \$(OBJECTS) main.cpp
 
 $ProgramName.pro: Makefile
 	echo "# Not indended to be used for anything except lupdate" > $ProgramName.pro
-	echo 'SOURCES=	license/tolicense.cpp\\' >> $ProgramName.pro
-	echo '	license/tolicenseui.cpp\\' >> $ProgramName.pro
+	echo 'SOURCES=	\\' >> $ProgramName.pro
 	echo '	main.cpp\\' >> $ProgramName.pro
 	echo '	toextratranslations.cpp\\' >> $ProgramName.pro
 	echo "	\$(SOURCES)" >> $ProgramName.pro
