@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include <stdio.h>
 
@@ -60,43 +63,24 @@
 #  ifdef TOAD
 #include "toadabout.h"
 #  else
-#    ifdef TO_LICENSE
 static const char *AboutText="<IMG SRC=largelogo.xpm><BR>\n"
-"Version %1 (<A HREF=http://www.globecom.se/tora>http://www.globecom.se/tora</A>)\n"
+"Version %1 (<A HREF=http://tora.sourceforge.net>http://tora.sourceforge.net</A>)\n"
 "<P>\n"
-"&copy; 2003 copyright of Quest Software, Inc\n"
+"&copy; 2003-2005 Quest Software, Inc. "
 "(<A HREF=http://www.quest.com>http://www.quest.com/</a>).<P>\n"
-"Written by Henrik Johnson.<P>\n"
-"This program is <B>NOT FREE SOFTWARE</B> although you are allowed to use it free of "
-"charge outside work. You are also allowed to evaluate the software at your work for "
-"<B>no more than 30 days</B> from the initial installation. See the license for more information.<P>\n"
-"You can purchase a commercial license at<BR>\n"
-"<A HREF=http://www.globecom.se/tora/register>http://www.globecom.se/tora/register</A><P>\n"
-"Uses the Qt library by TrollTech\n"
-"(<A HREF=http://www.troll.no>http://www.troll.no/</A>).<P>\n"
-"\n"
-"<HR BREAK=ALL>\n"
-"This program is distributed in the hope that it will be useful,\n"
-"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
-#    else
-static const char *AboutText="<IMG SRC=largelogo.xpm><BR>\n"
-"Version %1 (<A HREF=http://www.globecom.se/tora>http://www.globecom.se/tora</A>)\n"
-"<P>\n"
-"&copy; 2003 copyright of Quest Software, Inc\n"
-"(<A HREF=http://www.quest.com>http://www.quest.com/</a>).<P>\n"
-"Written by Henrik Johnson.<P>\n"
+"Portions &copy; 2005 other contributors<P>\n"
+"Written by Henrik Johnson with contributions by the Open Source community.<P>\n"
+"SourceForge project administered by Nathan Neulinger <A HREF=\"mailto:nneul@umr.edu\">nneul@umr.edu</A><P>\n"
 "This program is available\n"
 "under the GNU General Public License.\n"
 "Uses the Qt library by TrollTech\n"
-"(<A HREF=http://www.troll.no>http://www.troll.no/</A>).<P>\n"
+"(<A HREF=http://www.trolltech.com>http://www.trolltech.com/</A>).<P>\n"
 "\n"
 "<HR BREAK=ALL>\n"
 "This program is distributed in the hope that it will be useful,\n"
 "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
 "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
 "GNU General Public License for more details."
-#    endif
 "<HR BREAK=ALL>\n"
 "Contributors (In alphabetical order):<P>\n"
 "<UL>\n"
@@ -112,7 +96,9 @@ static const char *AboutText="<IMG SRC=largelogo.xpm><BR>\n"
 "<LI><B>Guillaume Moulard</B> - Log4PL/SQL documentation.\n"
 "</UL>\n"
 "Other contributors:<P>\n"
+"<B>Nuno Araujo</B>,\n"
 "<B>Ivan Brezina</B>,\n"
+"<B>Nathan Bryant</B>,\n"
 "<B>Robert Cheramy</B>,\n"
 "<B>Francesco Dandrea</B>,\n"
 "<B>Ferdinand Gassauer</B>,\n"
@@ -124,10 +110,14 @@ static const char *AboutText="<IMG SRC=largelogo.xpm><BR>\n"
 "<B>Bo Johansson</B>,\n"
 "<B>Olof Jnsson</B>,\n"
 "<B>Norbert Kiesel</B>,\n"
+"<B>Jacob Lauemølle</B>,\n"
 "<B>Laramie Leavitt</B>,\n"
 "<B>Paolo Magnoli</B>,\n"
+"<B>Vladimir Naprstek</B>,\n"
 "<B>Peter Nyborg</B>,\n"
 "<B>Frank Pavageau</B>,\n"
+"<B>Andreas Piesk</B>,\n"
+"<B>Thomas Porschberg</B>,\n"
 "<B>Jan Pruner</B>,\n"
 "<B>Jonas Rathert</B>,\n"
 "<B>Christopher R. Redinger</B>,\n"
@@ -135,6 +125,7 @@ static const char *AboutText="<IMG SRC=largelogo.xpm><BR>\n"
 "<B>Dennis Selsky</B>,\n"
 "<B>Roman Stepanov</B>,\n"
 "<B>Daniel Vrit</B>,\n"
+"<B>Matthias Wolle</B>,\n"
 "<B>Joachim Zetzsche</B>,\n"
 "<B>Massimiliano Ziccardi</B>...\n";
 #  endif
