@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -219,8 +222,14 @@ toLineChart *toBarChart::openCopy(QWidget *parent)
     // This is a really ugly workaround for a Qt layout bug
     QWidget *tmp=NULL;
     QWidget *tmp2=NULL;
+
+#if QT_VERSION < 0x030200
+    for (unsigned int i=0;i<toMainWidget()->workspace()->windowList().count();i++) {
+      QWidget *widget=toMainWidget()->workspace()->windowList().at(i);
+#else
     for (unsigned int i=0;i<toMainWidget()->workspace()->windowList(QWorkspace::CreationOrder).count();i++) {
       QWidget *widget=toMainWidget()->workspace()->windowList(QWorkspace::CreationOrder).at(i);
+#endif
       if (newWin!=widget)
 	tmp2=widget;
       else
