@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -127,7 +130,7 @@
 #define CONF_FILTER_TEXT  	"FilterText"
 
 
-char **toBrowserTool::pictureXPM(void)
+const char **toBrowserTool::pictureXPM(void)
 {
   return tobrowser_xpm;
 }
@@ -970,6 +973,27 @@ static toSQL SQLTriggerCols("toBrowser:TriggerCols",
 			    "  FROM SYS.ALL_TRIGGER_COLS\n"
 			    " WHERE Trigger_Owner = :f1<char[101]> AND Trigger_Name = :f2<char[101]>",
 			    "Columns used by trigger");
+#if DBLINK
+static toSQL SQLListDBLink("toBrowser:ListDBLink",
+			   "SELECT Db_Link, Owner FROM SYS.ALL_DB_LINKS\n"
+			   " WHERE (Owner = :f1<char[101]> or Owner='PUBLIC') and\n"
+			   " UPPER(DB_Link) like :f2<char[101]>",
+			   "List database links");
+static toSQL SQLListDBLinkDBA("toBrowser:ListDBLinkDBA",
+			      "SELECT Owner, Db_Link, Username, Host, Created\n"
+			      " FROM SYS.DBA_DB_LINK\n",
+			      "List database links as DBA");
+static toSQL SQLDBLinkInfo("toBrowser:DBLinkInformation",
+			    "SELECT * FROM Sys.all_db_links a\n"
+			    " WHERE Owner = :f1<char[101]>\n"
+			    "   AND DB_LINK = :f2<char[101]>",
+			    "Display information about database link");
+static toSQL SQLDBLinkSynonyms("toBrowser:DBLinkSynonyms",
+			       "SELECT * FROM Sys.all_synonyms a\n"
+			       " WHERE Owner = :f1<char[101]>\n"
+			       "   AND DB_LINK = :f2<char[101]>",
+			       "Display foreign synonyms");
+#endif
 
 static toSQL SQLMySQLAccess("toBrowser:MySQLAcess",
 			    "SHOW TABLES FROM mysql",
@@ -1265,7 +1289,7 @@ toBrowser::toBrowser(QWidget *parent,toConnection &connection)
   resultView->setResizeMode(QListView::AllColumns);
   connect(resultView,SIGNAL(selectionChanged()),
 	  this,SLOT(changeItem()));
-  connect(resultView,SIGNAL(displayMenu(QPopupMenu *)),this,SLOT(displayIndexMenu(QPopupMenu *)));
+  connect(resultView,SIGNAL(displayMenu(QPopupMenu *)),this,SLOT(displayIndexMenu(QPopupMenu *))); 
 
   box->resize(FIRST_WIDTH,resultView->height());
   splitter->setResizeMode(box,QSplitter::KeepSize);
@@ -1441,7 +1465,6 @@ toBrowser::toBrowser(QWidget *parent,toConnection &connection)
   curr->addTab(resultView,tr("&Columns"));
   SecondMap[TAB_TRIGGER_COLS]=resultView;
 
-
   resultView=new toResultLong(true,false,toQuery::Background,curr,TAB_TRIGGER_GRANTS);
   resultView->setSQL(SQLAnyGrants);
   resultView->setReadAll(true);
@@ -1456,6 +1479,51 @@ toBrowser::toBrowser(QWidget *parent,toConnection &connection)
   curr->addTab(resultExtract,tr("Script"));
   SecondMap[TAB_TRIGGER_EXTRACT]=resultExtract;
 
+  connect(curr,SIGNAL(currentChanged(QWidget *)),this,SLOT(changeSecondTab(QWidget *)));
+
+#ifdef DBLINK
+  splitter=new QSplitter(Horizontal,TopTab,TAB_DBLINK);
+  TopTab->addTab(splitter,tr("DBLinks"));
+  box=new QVBox(splitter);
+  toolbar=toAllocBar(box,tr("Database browser"));
+  new toBrowseButton(QPixmap((const char **)modconstraint_xpm),
+		     tr("Test DBLink"),
+		     tr("Test DBLink"),
+		     this,SLOT(testDBLink()),
+		     toolbar);
+  toolbar->addSeparator();
+  toolbar->setStretchableWidget(new QLabel(toolbar,TO_KDE_TOOLBAR_WIDGET));
+  
+  resultView=new toResultLong(true,false,toQuery::Background,box);
+  resultView->setReadAll(true);
+  connect(resultView,SIGNAL(done()),this,SLOT(firstDone()));
+  Map[TAB_DBLINK]=resultView;
+  resultView->setTabWidget(TopTab);
+  resultView->setSQL(SQLListDBLink);
+  resultView->resize(FIRST_WIDTH,resultView->height());
+  resultView->setResizeMode(QListView::AllColumns);
+  connect(resultView,SIGNAL(selectionChanged()),
+	  this,SLOT(changeItem()));
+  connect(resultView,SIGNAL(displayMenu(QPopupMenu *)),this,SLOT(displayIndexMenu(QPopupMenu *)));
+  box->resize(FIRST_WIDTH,resultView->height());
+  splitter->setResizeMode(box,QSplitter::KeepSize);
+  curr=new toTabWidget(splitter);
+  splitter->setResizeMode(curr,QSplitter::Stretch);
+
+  toResultItem *resultDBLink=new toResultItem(2,true,curr,TAB_DBLINK_INFO);
+  resultDBLink->setSQL(SQLDBLinkInfo);
+  curr->addTab(resultDBLink,tr("Info"));
+  SecondMap[TAB_DBLINK]=resultDBLink;
+  SecondMap[TAB_DBLINK_INFO]=resultDBLink;
+
+  resultView=new toResultLong(true,false,toQuery::Background,curr,TAB_DBLINK_SYNONYMS);
+  resultView->setSQL(SQLDBLinkSynonyms);
+  curr->addTab(resultView,tr("&Synonyms"));
+  SecondMap[TAB_DBLINK_SYNONYMS]=resultView;
+
+  connect(curr,SIGNAL(currentChanged(QWidget *)),this,SLOT(changeSecondTab(QWidget *)));
+#endif
+
   splitter=new QSplitter(Horizontal,TopTab,TAB_ACCESS);
   TopTab->addTab(splitter,tr("Access"));
 #ifdef TOEXTENDED_MYSQL
@@ -1520,7 +1588,7 @@ toBrowser::toBrowser(QWidget *parent,toConnection &connection)
   connect(AccessContent,SIGNAL(changesSaved()),this,SLOT(flushPrivs()));
 
   connect(curr,SIGNAL(currentChanged(QWidget *)),this,SLOT(changeSecondTab(QWidget *)));
-
+  
   ToolMenu=NULL;
   connect(toMainWidget()->workspace(),SIGNAL(windowActivated(QWidget *)),
 	  this,SLOT(windowActivated(QWidget *)));
@@ -2687,3 +2755,18 @@ void toBrowser::disableConstraints(void)
 {
   enableDisableConstraints("DISABLE");
 }
+
+void toBrowser::testDBLink(void)
+{
+  if(SecondText.isEmpty()) return;
+  toQList resultset;
+  try {
+    resultset=toQuery::readQueryNull(toCurrentConnection(this),
+				     "SELECT * FROM dual@"+SecondText);
+  } TOCATCH;
+//   } catch (...) {
+//     TOMessageBox::information(this, "Database link", SecondText);
+//   }
+  if(!resultset.empty())
+    TOMessageBox::information(this, "Database link", SecondText);
+}
