@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -1277,7 +1280,7 @@ void toConnection::delInit(const QString &sql)
   }
 }
 
-const std::list<QString> &toConnection::initStrings() const
+const std::list<QString> toConnection::initStrings() const
 {
   return InitStrings;
 }
@@ -1588,7 +1591,7 @@ bool toConnection::loadDiskCache()
    if (toTool::globalConfig(CONF_CACHE_DISK,DEFAULT_CACHE_DISK).isEmpty())
    	return false;
 
-   toConnection::objectName *cur;
+   toConnection::objectName *cur = 0;
    int objCounter = 0;
    int synCounter = 0;
 
@@ -1636,6 +1639,7 @@ bool toConnection::loadDiskCache()
        synCounter++;
      }
      ObjectNames.insert(ObjectNames.end(),(*cur));
+     delete cur; cur = 0;
    }
    return true;
 }
