@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,13 +29,16 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #ifndef TOCONNECTION_H
 #define TOCONNECTION_H
 
+#include "config.h"
 #include "toqvalue.h"
 #include "tothread.h"
 
@@ -815,7 +819,7 @@ public:
   /**
    * Get a list of the current init strings.
    */
-  const std::list<QString> &toConnection::initStrings() const;
+  const std::list<QString> initStrings() const;
 
   /** Return a string representation to address an object.
    * @param name The name to be quoted.
