@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -117,7 +120,7 @@
 class toDebugTool : public toTool {
   std::map<toConnection *,QWidget *> Windows;
 
-  virtual char **pictureXPM(void)
+  virtual const char **pictureXPM(void)
   { return todebug_xpm; }
 public:
   toDebugTool()
@@ -828,8 +831,8 @@ int toDebug::sync(void)
 }
 
 static struct TypeMapType {
-  char *Type;
-  char *Description;
+  const char *Type;
+  const char *Description;
   bool WantName;
   bool Declaration;
 } TypeMap[] = { { "FUNCTION",  "Function",   true ,true }, // Must be first in list
@@ -2175,6 +2178,10 @@ void toDebug::newSheet(void)
   toDebugText *text=new toDebugText(Breakpoints,Editors,this);
   connect(text,SIGNAL(insertedLines(int,int)),
 	  this,SLOT(reorderContent(int,int)));
+  if (!Schema->currentText().isEmpty())
+    text->setSchema(Schema->currentText());
+  else
+    text->setSchema(connection().user().upper());
   Editors->addTab(text,tr("Unknown"));
   Editors->showPage(text);
 }
