@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -78,7 +81,7 @@
 #include <qvbox.h>
 #include <qworkspace.h>
 
-#if QT_VERSION >= 300
+#if QT_VERSION >= 0x030000
 #include <qurloperator.h>
 #include <qnetwork.h>
 #include <qstyle.h>
@@ -179,14 +182,10 @@ const int toMain::TO_LAST_FILE_ID_END	= 5999;
 #define TO_HELP_ABOUT		902
 #define TO_HELP_LICENSE		903
 #define TO_HELP_QUOTES		904
-#define TO_HELP_REGISTER	905
 
 #define TO_TOOLS		1000
 #define TO_ABOUT_ID_OFFSET	(toMain::TO_TOOL_ABOUT_ID-TO_TOOLS)
 
-QString toCheckLicense(bool);
-bool toFreeware(void);
-
 toMain::toMain()
   : toMainWindow()
 {
@@ -260,7 +259,7 @@ toMain::toMain()
 #ifdef TOAD
 		       QPixmap((const char **)options_xpm),
 #endif
-		       tr("&Options..."),TO_EDIT_OPTIONS);
+		       tr("&Preferences..."),TO_EDIT_OPTIONS);
 
   QAccel *accel=new QAccel(this);
   accel->connectItem(accel->insertItem(toKeySequence(tr("Ctrl+Insert", "Edit|Copy"))),this,SLOT(copyButton()));
@@ -283,39 +282,6 @@ toMain::toMain()
   std::map<QCString,toTool *> &tools=toTool::tools();
 
   ToolsToolbar=toAllocBar(this,tr("Tools"));
-  ConnectionToolbar=toAllocBar(this,tr("Connections"));
-  new QToolButton(QPixmap((const char **)connect_xpm),
-		  tr("Connect to database"),
-		  tr("Connect to database"),
-		  this,SLOT(addConnection()),ConnectionToolbar);
-  DisconnectButton=new QToolButton(QPixmap((const char **)disconnect_xpm),
-				   tr("Disconnect current connection"),
-				   tr("Disconnect current connection"),
-				   this,SLOT(delConnection()),ConnectionToolbar);
-  DisconnectButton->setEnabled(false);
-#ifndef OAS
-  ConnectionToolbar->addSeparator();
-  NeedConnection[new QToolButton(QPixmap((const char **)commit_xpm),
-				 tr("Commit connection"),
-				 tr("Commit connection"),
-				 this,SLOT(commitButton()),ConnectionToolbar)]=true;
-  NeedConnection[new QToolButton(QPixmap((const char **)rollback_xpm),
-				 tr("Rollback connection"),
-				 tr("Rollback connection"),
-				 this,SLOT(rollbackButton()),ConnectionToolbar)]=true;
-  ConnectionToolbar->addSeparator();
-  NeedConnection[new QToolButton(QPixmap((const char **)stop_xpm),
-				 tr("Stop all running queries on connection"),
-				 tr("Stop all running queries on connection"),
-				 this,SLOT(stopButton()),ConnectionToolbar)]=true;
-#else
-  ConnectionToolbar->hide();
-#endif
-  ConnectionToolbar->addSeparator();
-  ConnectionSelection=new QComboBox(ConnectionToolbar,TO_KDE_TOOLBAR_WIDGET);
-  ConnectionSelection->setMinimumWidth(200);
-  ConnectionSelection->setFocusPolicy(NoFocus);
-  connect(ConnectionSelection,SIGNAL(activated(int)),this,SLOT(changeConnection()));
 
   EditToolbar=toAllocBar(this,tr("Application"));
 
@@ -373,6 +339,40 @@ toMain::toMain()
   CopyButton->setEnabled(false);
   PasteButton->setEnabled(false);
   SearchButton->setEnabled(false);
+  
+  ConnectionToolbar=toAllocBar(this,tr("Connections"));
+  new QToolButton(QPixmap((const char **)connect_xpm),
+		  tr("Connect to database"),
+		  tr("Connect to database"),
+		  this,SLOT(addConnection()),ConnectionToolbar);
+  DisconnectButton=new QToolButton(QPixmap((const char **)disconnect_xpm),
+				   tr("Disconnect current connection"),
+				   tr("Disconnect current connection"),
+				   this,SLOT(delConnection()),ConnectionToolbar);
+  DisconnectButton->setEnabled(false);
+#ifndef OAS
+  ConnectionToolbar->addSeparator();
+  NeedConnection[new QToolButton(QPixmap((const char **)commit_xpm),
+				 tr("Commit connection"),
+				 tr("Commit connection"),
+				 this,SLOT(commitButton()),ConnectionToolbar)]=true;
+  NeedConnection[new QToolButton(QPixmap((const char **)rollback_xpm),
+				 tr("Rollback connection"),
+				 tr("Rollback connection"),
+				 this,SLOT(rollbackButton()),ConnectionToolbar)]=true;
+  ConnectionToolbar->addSeparator();
+  NeedConnection[new QToolButton(QPixmap((const char **)stop_xpm),
+				 tr("Stop all running queries on connection"),
+				 tr("Stop all running queries on connection"),
+				 this,SLOT(stopButton()),ConnectionToolbar)]=true;
+#else
+  ConnectionToolbar->hide();
+#endif
+  ConnectionToolbar->addSeparator();
+  ConnectionSelection=new QComboBox(ConnectionToolbar,TO_KDE_TOOLBAR_WIDGET);
+  ConnectionSelection->setMinimumWidth(250);
+  ConnectionSelection->setFocusPolicy(NoFocus);
+  connect(ConnectionSelection,SIGNAL(activated(int)),this,SLOT(changeConnection()));
 
   ToolsMenu=new QPopupMenu(this);
 
@@ -388,10 +388,6 @@ toMain::toMain()
   HelpMenu->insertItem(tr("&Quotes..."),TO_HELP_QUOTES);
 #endif
   HelpMenu->setAccel(toKeySequence(tr("F1", "Help|Help")),TO_HELP_CONTEXT);
-  if (!toFreeware()) {
-    HelpMenu->insertSeparator();
-    HelpMenu->insertItem(tr("&Register..."),TO_HELP_REGISTER);
-  }
 
   int toolID=TO_TOOLS;
   SQLEditor=-1;
@@ -510,12 +506,6 @@ toMain::toMain()
 
   QString welcome;
 
-  do {
-    welcome=toCheckLicense(false);
-  } while(welcome.isNull());
-
-  toStatusMessage(tr(welcome),true);
-
   connect(&Poll,SIGNAL(timeout()),this,SLOT(checkCaching()));
   connect(toMainWidget()->workspace(),SIGNAL(windowActivated(QWidget *)),
 	  this,SLOT(windowActivated(QWidget *)));
@@ -533,42 +523,6 @@ toMain::toMain()
   else
     show();
 
-#if QT_VERSION >= 300 && !defined (TO_NO_NEW_CHECK) && !defined (OAS)
-  if (toTool::globalConfig(CONF_UPGRADE_CHECK,"Not specified")=="Not specified") {
-    switch(TOMessageBox::information(this,tr("Check for upgrades?"),
-				     tr("Do you want " TOAPPNAME " to automatically check\n"
-					TOHOMEPAGE " for updates on startup?\n"
-					"During this check no information about your computer\n"
-					"including version is transmitted to the site"),
-				     tr("&Yes"),tr("&No"),QString::null,0)) {
-    case 0:
-      toTool::globalSetConfig(CONF_UPGRADE_CHECK,"Yes");
-      break;
-    case 1:
-      toTool::globalSetConfig(CONF_UPGRADE_CHECK,"");
-      break;
-    }
-  }
-  if (toTool::globalConfig(CONF_UPGRADE_CHECK,"Not specified")=="Yes") {
-    qInitNetworkProtocols();
-    VersionUrl=new QUrlOperator(QString::fromLatin1(TOHOMEPAGE
-#ifdef TOAD
-						    "/mysqlversion.html"
-#else
-						    "/version.php?" TOTYPE
-						    "=1"
-#endif
-						    ));
-    VersionUrl->get();
-    connect(VersionUrl,SIGNAL(data(const QByteArray &,QNetworkOperation *)),
-	    this,SLOT(versionData(const QByteArray &,QNetworkOperation *)));
-    connect(VersionUrl,SIGNAL(finished(QNetworkOperation *)),
-	    this,SLOT(versionFinished(QNetworkOperation *)));
-  } else {
-    VersionUrl=NULL;
-  }
-#endif
-
   toBackground::init();
 
   if (Connections.size()==0) {
@@ -681,8 +635,13 @@ void toMain::windowsMenu(void)
   QRegExp strip(QString::fromLatin1(" <[0-9]+>$"));
   int id=0;
   unsigned int i;
+#if QT_VERSION < 0x030200
+  for (i=0;i<workspace()->windowList().count();i++) {
+    QWidget *widget=workspace()->windowList().at(i);
+#else
   for (i=0;i<workspace()->windowList(QWorkspace::CreationOrder).count();i++) {
     QWidget *widget=workspace()->windowList(QWorkspace::CreationOrder).at(i);
+#endif
     if (widget&&!widget->isHidden()) {
       if (first)
 	first=false;
@@ -692,8 +651,13 @@ void toMain::windowsMenu(void)
 	WindowsMenu->insertItem(caption,TO_WINDOWS_WINDOWS+i);
       else
 	WindowsMenu->changeItem(TO_WINDOWS_WINDOWS+i,caption);
+#if QT_VERSION < 0x030200
+      WindowsMenu->setItemChecked(TO_WINDOWS_WINDOWS+i,
+				  workspace()->activeWindow()==workspace()->windowList().at(i));
+#else
       WindowsMenu->setItemChecked(TO_WINDOWS_WINDOWS+i,
 				  workspace()->activeWindow()==workspace()->windowList(QWorkspace::CreationOrder).at(i));
+#endif
       if (i<9) {
 	WindowsMenu->setAccel(Key_1+id|CTRL,TO_WINDOWS_WINDOWS+i);
 	caption+=QString::fromLatin1(" <");
@@ -732,8 +696,13 @@ void toMain::commandCallback(int cmd)
     if (Tools[cmd-TO_ABOUT_ID_OFFSET])
       Tools[cmd-TO_ABOUT_ID_OFFSET]->about(this);
   } else if (cmd>=TO_WINDOWS_WINDOWS&&cmd<=TO_WINDOWS_END) {
+#if QT_VERSION < 0x030200
+    if (cmd-TO_WINDOWS_WINDOWS<int(workspace()->windowList().count())) {
+      QWidget *widget=workspace()->windowList().at(cmd-TO_WINDOWS_WINDOWS);
+#else
     if (cmd-TO_WINDOWS_WINDOWS<int(workspace()->windowList(QWorkspace::CreationOrder).count())) {
       QWidget *widget=workspace()->windowList(QWorkspace::CreationOrder).at(cmd-TO_WINDOWS_WINDOWS);
+#endif
       widget->raise();
       widget->setFocus();
     }
@@ -857,16 +826,19 @@ void toMain::commandCallback(int cmd)
 	about.exec();
       }
       break;
-    case TO_HELP_REGISTER:
-      toCheckLicense(true);
-      break;
     case TO_EDIT_OPTIONS:
       toPreferences::displayPreferences(this);
       break;
     case TO_WINDOWS_CLOSE_ALL:
+#if QT_VERSION < 0x030200
+      while (workspace()->windowList().count()>0&&workspace()->windowList().at(0))
+	if (workspace()->windowList().at(0)&&
+	    !workspace()->windowList().at(0)->close(true))
+#else
       while (workspace()->windowList(QWorkspace::CreationOrder).count()>0&&workspace()->windowList(QWorkspace::CreationOrder).at(0))
 	if (workspace()->windowList(QWorkspace::CreationOrder).at(0)&&
 	    !workspace()->windowList(QWorkspace::CreationOrder).at(0)->close(true))
+#endif
 	  return;
       break;
     case TO_WINDOWS_CLOSE:
@@ -1138,7 +1110,7 @@ void toMain::editEnable(toEditWidget *edit)
 		     edit->selectAllEnabled(),
 		     edit->readAllEnabled());
 
-#if QT_VERSION >= 300
+#if QT_VERSION >= 0x030000
     // Set Selection Mode on X11
     QClipboard *clip=qApp->clipboard();
     if(clip->supportsSelection())
@@ -1391,8 +1363,13 @@ void toMain::exportData(std::map<QCString,QString> &data,const QCString &prefix)
     }
 
     id=1;
+#if QT_VERSION < 0x030200
+    for (unsigned int i=0;i<workspace()->windowList().count();i++) {
+      toToolWidget *tool=dynamic_cast<toToolWidget *>(workspace()->windowList().at(i));
+#else
     for (unsigned int i=0;i<workspace()->windowList(QWorkspace::CreationOrder).count();i++) {
       toToolWidget *tool=dynamic_cast<toToolWidget *>(workspace()->windowList(QWorkspace::CreationOrder).at(i));
+#endif
       if (tool) {
 	QCString key=prefix+":Tools:"+QString::number(id).latin1();
 	tool->exportData(data,key);
@@ -1530,10 +1507,17 @@ void toMain::closeSession(void)
   } TOCATCH
 
   // Workaround in bug in Qt 3.0.0
+#if QT_VERSION < 0x030200
+  while (workspace()->windowList().count()>0&&workspace()->windowList().at(0))
+    if (workspace()->windowList().at(0)&&
+	!workspace()->windowList().at(0)->close(true))
+      return;
+#else
   while (workspace()->windowList(QWorkspace::CreationOrder).count()>0&&workspace()->windowList(QWorkspace::CreationOrder).at(0))
     if (workspace()->windowList(QWorkspace::CreationOrder).at(0)&&
 	!workspace()->windowList(QWorkspace::CreationOrder).at(0)->close(true))
       return;
+#endif
   while (Connections.end()!=Connections.begin()) {
     if (!delConnection())
       return;
@@ -1579,7 +1563,7 @@ void toMain::displayMessage(void)
   for(QString str=toShift(StatusMessages);!str.isEmpty();str=toShift(StatusMessages)) {
     toMessageUI dialog(toMainWidget(),NULL,true);
     dialog.Message->setReadOnly(true);
-#if QT_VERSION >= 300
+#if QT_VERSION >= 0x030000
     dialog.Icon->setPixmap(QApplication::style().stylePixmap(QStyle::SP_MessageBoxWarning));
 #endif
     dialog.Message->setText(str);
@@ -1601,25 +1585,6 @@ void toMain::displayMessage(const QString &str)
   QTimer::singleShot(1,this,SLOT(displayMessage()));
 }
 
-void toMain::versionData(const QByteArray &data,QNetworkOperation *)
-{
-#if QT_VERSION >= 300
-  if (data.size()>0&&data.data()!=NULL)
-    VersionString+=QCString(data.data(),data.size());
-#endif
-}
-
-void toMain::versionFinished(QNetworkOperation *)
-{
-#if QT_VERSION >= 300
-  int i=VersionString.find('\n');
-  if (i>=0)
-    VersionString=VersionString.mid(0,i);
-  if (VersionString[0].isNumber()&&VersionString > TOVERSION)
-    toStatusMessage(tr("A new version of " TOAPPNAME " (%1) is available from\n\n" TOHOMEPAGE).arg(VersionString));
-#endif
-}
-
 void toMain::updateKeepAlive(void)
 {
   int keepAlive=toTool::globalConfig(CONF_KEEP_ALIVE,"0").toInt();
