@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -362,7 +365,7 @@ public:
     virtual void cancel(void);
     virtual bool eof(void)
     {
-      if (!Query)
+      if (!Query || Cancel)
 	return true;
       return Query->eof();
     }
@@ -965,9 +968,10 @@ void toOracleProvider::oracleQuery::cancel(void)
   oracleSub *conn=dynamic_cast<oracleSub *>(query()->connectionSub());
   if (!conn)
     throw QString::fromLatin1("Internal error, not oracle sub connection");
-  if (Running)
+  if (Running) {
     conn->Connection->cancel();
-  else {
+    Cancel=true;
+  } else {
     Cancel=true;
     conn->Lock.up();
   }
@@ -1070,7 +1074,7 @@ toConnectionSub *toOracleProvider::oracleConnection::createConnection(void)
 		      "BEGIN\n"
 		      "  SYS.DBMS_APPLICATION_INFO.SET_CLIENT_INFO('" TOAPPNAME
 #ifndef OAS
-		      " (http://www.globecom.se/tora)"
+		      " (http://tora.sourceforge.net)"
 #endif
 		      "');\n"
 		      "  SYS.DBMS_APPLICATION_INFO.SET_MODULE('" TOAPPNAME "','Access Database');\n"
