@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -222,7 +225,7 @@ static toSQL SQLStopProfiler("toProfiler:StopProfiler",
 			     "Stop profiler run");
 
 class toProfilerTool : public toTool {
-  virtual char **pictureXPM(void)
+  virtual const char **pictureXPM(void)
   { return clock_xpm; }
 public:
   toProfilerTool()
