@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -41,6 +44,9 @@
 #include "tosql.h"
 #include "totool.h"
 
+#include <ctype.h>
+#include <string.h>
+
 #include <qapplication.h>
 #include <qcheckbox.h>
 #include <qgroupbox.h>
@@ -1538,6 +1544,7 @@ public:
   virtual std::list<QString> providedOptions(const QCString &provider)
   {
     std::list<QString> ret;
+#if QT_VERSION >= 0x030200
     if (provider=="MySQL") {
       ret.insert(ret.end(),"*SSL");
       ret.insert(ret.end(),"*Compress");
@@ -1545,6 +1552,7 @@ public:
       ret.insert(ret.end(),"Ignore Space");
       ret.insert(ret.end(),"No Schema");
     }
+#endif
     return ret;
   }
   virtual std::list<QString> providedDatabases(const QCString &,const QString &,const QString &,const QString &)
@@ -1556,7 +1564,7 @@ public:
     return ret;
   }
 
-  static qSqlSub *toQSqlProvider::createConnection(toConnection &conn);
+  static qSqlSub* createConnection(toConnection &conn);
 };
 
 static toQSqlProvider QSqlProvider;
@@ -1660,6 +1668,7 @@ toQSqlProvider::qSqlSub *toQSqlProvider::createConnection(toConnection &conn)
     db->setPort(host.mid(pos+1).toInt());
   }
 
+#if QT_VERSION >= 0x030200 
   QString opt;
 
   std::set<QString> options=conn.options();
@@ -1671,9 +1680,10 @@ toQSqlProvider::qSqlSub *toQSqlProvider::createConnection(toConnection &conn)
     opt+=";CLIENT_NO_SCHEMA";
   if (options.find("SSL")!=options.end())
     opt+=";CLIENT_SSL";
-
+ 
   if (!opt.isEmpty())
     db->setConnectOptions(opt.mid(1));	// Strip first ; character
+#endif
 
   db->open(conn.user(),conn.password());
   if (!db->isOpen()) {
