@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -338,7 +341,7 @@ toResultContentEditor::~toResultContentEditor()
 {
   saveUnsaved();
   delete Query;
-  delete BinaryColumns;
+  delete [] BinaryColumns;
 }
 
 void toResultContentEditor::wrongUsage(void)
@@ -441,7 +444,7 @@ void toResultContentEditor::poll(void)
       if (numRows()==0) {
 	Description=Query->describe();
 
-	delete BinaryColumns;
+	delete [] BinaryColumns;
 	BinaryColumns=new bool[Description.size()];
 	for(unsigned int j=0;j<Description.size();j++)
 	  BinaryColumns[j]=false;
@@ -484,7 +487,7 @@ void toResultContentEditor::poll(void)
 	setUpdatesEnabled(false);
 	setNumRows(rows);
 
-#if QT_VERSION >= 300
+#if QT_VERSION >= 0x030000
 	int origRow=Row;
 #endif
 	while(dataSize>0) {
@@ -495,7 +498,7 @@ void toResultContentEditor::poll(void)
 	  }
 	  Row++;
 	}
-#if QT_VERSION >= 300
+#if QT_VERSION >= 0x030000
 	if (numRows()<STOP_RESIZE_ROW)
 	  for(int j=0;j<numCols();j++) {
 	    int width=columnWidth(j);
@@ -1261,7 +1264,7 @@ bool toResultContentEditor::searchNext(toSearchReplace *search)
     if (search->findString(text(row,col),pos,endPos)) {
       setCurrentCell(row,col);
 
-#if QT_VERSION >= 300
+#if QT_VERSION >= 0x030000
       editCell(row,col);
       if (CurrentEditor)
 	CurrentEditor->setSelection(pos,endPos-pos);
