@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -500,6 +503,12 @@ toListView::toListView(QWidget *parent,const char *name,WFlags f)
   LastMove=QPoint(-1,-1);
 }
 
+toListView::~toListView()
+{
+  delete AllTip;
+  AllTip = 0;
+}
+
 void toListView::contentsMouseDoubleClickEvent (QMouseEvent *e)
 {
   QPoint p=e->pos();
@@ -692,21 +701,41 @@ QListViewItem *toListView::printPage(TOPrinter *printer,QPainter *painter,QListV
 void toListView::editPrint(void)
 {
   TOPrinter printer;
-  printer.setMinMax(1,1000);
-  printer.setFromTo(1,1000);
-  if (printer.setup()) {
-    printer.setCreator(tr(TOAPPNAME));
-    QPainter painter(&printer);
 
-    QListViewItem *item=firstChild();
-    int column=0;
-    int tree=rootIsDecorated()?treeStepSize():0;
-    int page=1;
-    while(page<printer.fromPage()&&
-	  (item=printPage(&printer,&painter,item,column,tree,page++,false)))
-      painter.resetXForm();
-    while((item=printPage(&printer,&painter,item,column,tree,page++))&&
-	  (printer.toPage()==0||page<=printer.toPage())) {
+  std::map<int,int> PageColumns;
+  std::map<int,QListViewItem *> PageItems;
+
+  int column=0;
+  int tree=rootIsDecorated()?treeStepSize():0;
+  int page=1;
+  PageColumns[1]=0;
+  QListViewItem *item=PageItems[1]=firstChild();
+
+  printer.setCreator(tr(TOAPPNAME));
+  QPainter painter(&printer);
+
+  while((item=printPage(&printer,&painter,item,column,tree,page++,false))) {
+    PageColumns[page]=column;
+    PageItems[page]=item;
+  }
+
+  printer.setMinMax(1,page-1);
+  printer.setFromTo(1,page-1);
+  if (printer.setup()) {
+#ifdef TO_KDE
+    QValueList<int> pages=printer.pageList();
+#else
+    QValueList<int> pages;
+    for(int i=printer.fromPage();i<=printer.toPage()||(printer.toPage()==0&&i<page);i++)
+      pages+=i;
+#endif
+
+    for(QValueList<int>::iterator pageit=pages.begin();pageit!=pages.end();pageit++) {
+      page=*pageit;
+      item=PageItems[page];
+      column=PageColumns[page];
+
+      printPage(&printer,&painter,item,column,tree,page,true);
       printer.newPage();
       painter.resetXForm();
       qApp->processEvents();
