@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,13 +29,16 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #ifndef TORESULTVIEW_H
 #define TORESULTVIEW_H
 
+#include "config.h"
 #include "toeditwidget.h"
 #include "toresult.h"
 #include "toresultlistformatui.h"
@@ -407,6 +411,7 @@ public:
    * @param f Widget flags.
    */
   toListView(QWidget *parent,const char *name=NULL,WFlags f=0);
+  virtual ~toListView();
 
   /** Get SQL name of list.
    */
