@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -435,7 +438,7 @@ bool toSQLParse::statement::operator == (const statement &stat) const
   return true;
 }
 
-static char *Operators[]={":=",
+static const char *Operators[]={":=",
 			  "=>",
 			  "||",
 			  "**",
@@ -779,8 +782,10 @@ toSQLParse::statement toSQLParse::parseStatement(tokenizer &tokens,bool declare,
     } else if (first==("ASSIGN")||
 	       first==("SET")||
 	       first==("PROMPT")||
+	       first==("COLUMN")||
 	       first==("SPOOL")||
 	       first==("STORE")||
+	       first==("REMARK")||
 	       first==("REM")) {
       ret.subTokens().insert(ret.subTokens().end(),statement(statement::Keyword,token,tokens.line()));
       int line=tokens.line();
