@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "tochangeconnection.h"
 #include "toconf.h"
@@ -128,7 +131,7 @@ void toStoragePrefs::saveSetting(void)
 
 class toStorageTool : public toTool {
 protected:
-  virtual char **pictureXPM(void)
+  virtual const char **pictureXPM(void)
   { return tostorage_xpm; }
 public:
   toStorageTool()
@@ -795,7 +798,9 @@ toStorage::toStorage(QWidget *main,toConnection &connection)
   Objects->addColumn(tr("Blocks"));
   Objects->setColumnAlignment(3,AlignRight);
   Objects->setColumnAlignment(4,AlignRight);
-
+  Objects->setSorting(0);
+  Objects->setShowSortIndicator(TRUE);
+    
   Extents=new toStorageExtent(ExtentParent);
   Objects->setSelectionMode(QListView::Single);
   Storage->setSelectionMode(QListView::Single);
