@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -387,7 +390,7 @@ class toTemplateTool : public toTool {
   TODock *Dock;
   toTemplate *Window;
 protected:
-  virtual char **pictureXPM(void)
+  virtual const char **pictureXPM(void)
   { return totemplate_xpm; }
 public:
   toTemplateTool()
@@ -401,14 +404,14 @@ public:
       Dock=toAllocDock(qApp->translate("toTemplateTool","Template"),QString::null,*toolbarImage());
       Window=new toTemplate(Dock);
     } else if (Dock->isHidden()) {
-#if TO_KDE
+#ifdef TO_KDE
       toAttachDock(Dock,Window,QMainWindow::Left);
 #else
       Dock->show();
 #endif
       Window->showResult(true);
     } else {
-#if TO_KDE
+#ifdef TO_KDE
       toAttachDock(Dock,Window,QMainWindow::Minimized);
 #else
       Dock->hide();
@@ -533,13 +536,13 @@ void toTemplate::showResult(bool show)
     return;
 
   if (show) {
-#if TO_KDE
+#ifdef TO_KDE
     toAttachDock((TODock *)Result,Frame,QMainWindow::Bottom);
 #else
     Result->show();
 #endif
   } else {
-#if TO_KDE
+#ifdef TO_KDE
     toAttachDock((TODock *)Result,Frame,QMainWindow::Minimized);
 #else
     Result->hide();
