@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -45,6 +48,24 @@
 
 #ifdef QT_THREAD_SUPPORT
 
+#ifdef WIN32
+bool toWaitCondition::wait(QMutex *mutex, unsigned long time)
+{
+    bool status = FALSE;
+    
+    // this implementation relies on existing wait() method
+    if (mutex) {
+        mutex->unlock();
+        status = QWaitCondition::wait(time);
+        mutex->lock();
+    }
+    else
+        status = QWaitCondition::wait(time);
+        
+    return status;
+}
+#endif
+
 void toSemaphore::up(void)
 {
   Mutex.lock();
@@ -57,8 +78,9 @@ void toSemaphore::up(void)
 void toSemaphore::down(void)
 {
   Mutex.lock();
-  while(Value<=0)
+  while(Value<=0) {
     Condition.wait(&Mutex);
+  }
   Value--;
   Mutex.unlock();
 }
