@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,13 +29,17 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #ifndef TOTHREAD_H
 #define TOTHREAD_H
 
+#include "config.h"
+
 #include <qthread.h>
 
 /** This is an abstract class that defines something that is to be performed by a
@@ -69,6 +74,22 @@ public:
 
 #else
 
+#ifdef WIN32
+/**
+ * Implementing missing functionality from QWaitCondition for Win32
+ */
+class toWaitCondition : public QWaitCondition {
+public:
+  // create the wait condition
+  toWaitCondition():QWaitCondition() {}
+
+  // this method is not implemented in QT Free port
+  bool wait( QMutex *mutex, unsigned long time = ULONG_MAX );
+
+};
+
+#endif
+
 /** Encapsulation of pthread semaphores. A semaphore can be raise to any value
  * but will wait till raised above zero when lowered below 0. Can also be implemented
  * without pthreads using Qt multithreaded primitives. Observe that these function
@@ -78,7 +99,11 @@ public:
 class toSemaphore {
 private:
   QMutex Mutex;
+#ifdef WIN32
+  toWaitCondition Condition;
+#else
   QWaitCondition Condition;
+#endif
   int Value;
 public:
   /** Create semaphore
