@@ -1,7 +1,8 @@
-//***************************************************************************
-/*
+/*****
+ *
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2003 Quest Software, Inc
+ * Copyright (C) 2003-2005 Quest Software, Inc
+ * Portions Copyright (C) 2005 Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +29,11 @@
  *      these libraries without written consent from Quest Software, Inc.
  *      Observe that this does not disallow linking to the Qt Free Edition.
  *
+ *      You may link this product with any GPL'd Qt library such as Qt/Free
+ *
  * All trademarks belong to their respective owners.
  *
- ****************************************************************************/
+ *****/
 
 #include "utils.h"
 
@@ -102,6 +105,7 @@
 #include "icons/executestep.xpm"
 #include "icons/explainplan.xpm"
 #include "icons/filesave.xpm"
+#include "icons/insertsaved.xpm"
 #include "icons/previous.xpm"
 #include "icons/refresh.xpm"
 #include "icons/stop.xpm"
@@ -197,7 +201,7 @@ public slots:
 
 class toWorksheetTool : public toTool {
 protected:
-  virtual char **pictureXPM(void)
+  virtual const char **pictureXPM(void)
   { return toworksheet_xpm; }
 public:
   toWorksheetTool()
@@ -244,6 +248,9 @@ public:
     } else if (toCheckKeyEvent(e,QKeySequence(qApp->translate("toWorksheet","F7", "Worksheet|Execute saved SQL")))) {
       Worksheet->executeSaved();
       e->accept();
+    } else if (toCheckKeyEvent(e,QKeySequence(qApp->translate("toWorksheet","Shift+F7", "Worksheet|Insert saved SQL")))) {
+      Worksheet->insertSaved();
+      e->accept();
     } else if (toCheckKeyEvent(e,QKeySequence(qApp->translate("toWorksheet","F4", "Worksheet|Describe under cursor")))) {
       Worksheet->describe();
       e->accept();
@@ -522,6 +529,15 @@ void toWorksheet::setup(bool autoLoad)
 		    toolbar);
     toolbar->addSeparator();
 
+    InsertSavedButton=new toPopupButton(QPixmap((const char **)insertsaved_xpm),
+                                  tr("Insert current saved SQL"),
+                                  tr("Insert current saved SQL"),
+                                  toolbar);
+    InsertSavedMenu=new QPopupMenu(InsertSavedButton);
+    InsertSavedButton->setPopup(InsertSavedMenu);
+    connect(InsertSavedMenu,SIGNAL(aboutToShow()),this,SLOT(showInsertSaved()));
+    connect(InsertSavedMenu,SIGNAL(activated(int)),this,SLOT(insertSaved(int)));
+
     SavedButton=new toPopupButton(QPixmap((const char **)recall_xpm),
 				  tr("Run current saved SQL"),
 				  tr("Run current saved SQL"),
@@ -530,6 +546,7 @@ void toWorksheet::setup(bool autoLoad)
     SavedButton->setPopup(SavedMenu);
     connect(SavedMenu,SIGNAL(aboutToShow()),this,SLOT(showSaved()));
     connect(SavedMenu,SIGNAL(activated(int)),this,SLOT(executeSaved(int)));
+
     new QToolButton(QPixmap((const char **)previous_xpm),
 		    tr("Save last SQL"),
 		    tr("Save last SQL"),
@@ -867,6 +884,7 @@ void toWorksheet::query(const QString &str,execType type)
     if (first==QString::fromLatin1("REM")||
 	first==QString::fromLatin1("ASSIGN")||
 	first==QString::fromLatin1("PROMPT")||
+	first==QString::fromLatin1("COLUMN")||
 	first==QString::fromLatin1("SPOOL")||
 	first==QString::fromLatin1("STORE")) {
       QString t=tr("Ignoring SQL*Plus command");
@@ -1371,7 +1389,8 @@ void toWorksheet::enableStatistic(bool ena)
   if (ena) {
     Result->setStatistics(Statistics);
     ResultTab->setTabEnabled(StatTab,true);
-    ToolMenu->setItemChecked(TO_ID_STATISTICS,true);
+    if (ToolMenu)
+      ToolMenu->setItemChecked(TO_ID_STATISTICS,true);
     Statistics->clear();
     if (!WorksheetTool.config(CONF_TIMED_STATS,"Yes").isEmpty()) {
       try {
@@ -1466,6 +1485,20 @@ void toWorksheet::executeSaved(void)
   }
 }
 
+void toWorksheet::insertSaved(void)
+{
+  if (Light)
+    return;
+
+  LastLine=LastOffset=-1;
+
+  if (InsertSavedLast.length()>0) {
+    try {
+      Editor->setText(toSQL::string(InsertSavedLast,connection()));
+    } TOCATCH
+  }
+}
+
 void toWorksheet::executeSaved(int id)
 {
   std::list<QCString> def=toSQL::range(TOWORKSHEET);
@@ -1479,6 +1512,19 @@ void toWorksheet::executeSaved(int id)
   }
 }
 
+void toWorksheet::insertSaved(int id)
+{
+  std::list<QCString> def=toSQL::range(TOWORKSHEET);
+  for(std::list<QCString>::iterator i=def.begin();i!=def.end();i++) {
+    id--;
+    if (id==0) {
+      InsertSavedLast=*i;
+      insertSaved();
+      break;
+    }
+  }
+}
+
 void toWorksheet::showSaved(void)
 {
   static QRegExp colon(QString::fromLatin1(":"));
@@ -1525,6 +1571,53 @@ void toWorksheet::showSaved(void)
   }
 }
 
+void toWorksheet::showInsertSaved(void)
+{
+  static QRegExp colon(QString::fromLatin1(":"));
+  std::list<QCString> def=toSQL::range(TOWORKSHEET);
+  InsertSavedMenu->clear();
+  std::map<QString,QPopupMenu *> menues;
+  int id=0;
+  for(std::list<QCString>::iterator sql=def.begin();sql!=def.end();sql++) {
+
+    id++;
+
+    QStringList spl=QStringList::split(colon,QString::fromLatin1(*sql));
+    spl.remove(spl.begin());
+
+    if (spl.count()>0) {
+      QString name=spl.last();
+      spl.remove(spl.fromLast());
+
+      QPopupMenu *menu;
+      if (spl.count()==0)
+	menu=InsertSavedMenu;
+      else {
+	QStringList exs=spl;
+	while (exs.count()>0&&menues.find(exs.join(QString::fromLatin1(":")))==menues.end())
+	  exs.remove(exs.fromLast());
+	if (exs.count()==0)
+	  menu=InsertSavedMenu;
+	else
+	  menu=menues[exs.join(QString::fromLatin1(":"))];
+	QString subname=exs.join(QString::fromLatin1(":"));
+	for (unsigned int i=exs.count();i<spl.count();i++) {
+	  QPopupMenu *next=new QPopupMenu(this);
+	  connect(next,SIGNAL(activated(int)),this,SLOT(insertSaved(int)));
+	  if (i!=0)
+	    subname+=QString::fromLatin1(":");
+	  subname+=spl[i];
+	  menu->insertItem(spl[i],next);
+	  menu=next;
+	  menues[subname]=menu;
+	}
+      }
+      menu->insertItem(name,id);
+    }
+  }
+}
+
+
 void toWorksheet::editSaved(void)
 {
   QCString sql=TOWORKSHEET;
@@ -1792,6 +1885,9 @@ void toWorksheet::displayMenu(QPopupMenu *menu)
     menu->insertItem(tr("Execute Saved SQL"),
 		     this,SLOT(executeSaved()),
 		     toKeySequence(tr("F7", "Worksheet|Execute saved SQL")));
+    menu->insertItem(tr("Insert Saved SQL"),
+		     this,SLOT(insertSaved()),
+		     toKeySequence(tr("Shift+F7", "Worksheet|Insert saved SQL")));
     menu->insertItem(tr("Select Saved SQL"),
 		     this,SLOT(selectSaved()),
 		     toKeySequence(tr("Ctrl+Shift+S", "Worksheet|Select saved SQL")));
